import * as React from "react";
import { useTheme } from "@mui/material/styles";
import Card from "@mui/material/Card";
import CardContent from "@mui/material/CardContent";
import Typography from "@mui/material/Typography";
import { LineChart } from "@mui/x-charts/LineChart";
import { FormControl, MenuItem, Select } from "@mui/material";
import ExpandMoreIcon from "@mui/icons-material/ExpandMore";
import useMediaQuery from "@mui/material/useMediaQuery";

function AreaGradient({ color, id }: { color: string; id: string }) {
  return (
    <defs>
      <linearGradient id={id} x1="50%" y1="0%" x2="50%" y2="100%">
        <stop offset="0%" stopColor={color} stopOpacity={0.5} />
        <stop offset="100%" stopColor={color} stopOpacity={0} />
      </linearGradient>
    </defs>
  );
}

function getDaysInMonth(month: number, year: number) {
  const date = new Date(year, month, 0);
  const monthName = date.toLocaleDateString("en-US", {
    month: "short",
  });
  const daysInMonth = date.getDate();
  const days = [];
  let i = 1;
  while (days.length < daysInMonth) {
    days.push(`${monthName} ${i}`);
    i += 1;
  }
  return days;
}

export default function LineChartCard() {
  const theme = useTheme();
  const isXsScreen = useMediaQuery(theme.breakpoints.down("sm"));
  const isSmScreen = useMediaQuery(theme.breakpoints.between("sm", "md"));
  
  const data = getDaysInMonth(4, 2024);
  const colorPalette = [theme.palette.primary.main];
  const [selectedOption, setSelectedOption] = React.useState("Weekly");

  const handleChange = (event: { target: { value: React.SetStateAction<string> } }) => {
    setSelectedOption(event.target.value);
  };

  // Calculate responsive dimensions
  const getChartHeight = () => {
    if (isXsScreen) return 200;
    if (isSmScreen) return 220;
    return 250;
  };

  const getChartMargin = () => {
    if (isXsScreen) return { left: 35, right: 10, top: 15, bottom: 15 };
    if (isSmScreen) return { left: 40, right: 15, top: 18, bottom: 18 };
    return { left: 50, right: 20, top: 20, bottom: 20 };
  };

  return (
    <Card
      variant="outlined"
      sx={{
        width: "100%",
        height: "auto",
        minHeight: { xs: "360px", sm: "400px", md: "444px" },
        borderRadius: "16px",
        border: "none",
        "*:where([data-mui-color-scheme='dark']) &": {
          backgroundColor: "#202020",
        },
      }}
    >
      <CardContent sx={{ padding: { xs: 2, md: 3 }, "&:last-child": { paddingBottom: { xs: 2, md: 3 } } }}>
        <div
          style={{
            display: "flex",
            alignItems: "center",
            flexDirection: isXsScreen ? "column" : "row",
            color: "#F2F2F2",
            marginBottom: isXsScreen ? 16 : 0,
          }}
        >
          <Typography
            variant="h6"
            align={isXsScreen ? "center" : "left"}
            color="#F2F2F2"
            sx={{
              fontWeight: 500,
              fontSize: { xs: "16px", sm: "17px", md: "18px" },
              lineHeight: "24px",
              marginBottom: isXsScreen ? 2 : 0,
              width: isXsScreen ? "100%" : "auto",
            }}
          >
            Sales Stats
          </Typography>
          <FormControl
            sx={{
              mt: isXsScreen ? 0 : 2,
              mb: isXsScreen ? 0 : 2,
              backgroundColor: "#202020",
              marginLeft: isXsScreen ? 0 : "auto",
              marginRight: isXsScreen ? 0 : "16px",
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
              color: "#F2F2F2",
              width: { xs: "100%", sm: "140px", md: "149px" },
              height: { xs: "40px", md: "44px" },
              padding: { xs: "8px 12px", md: "12px 16px" },
              gap: "8px",
            }}
          >
            <Select
              value={selectedOption}
              onChange={handleChange}
              sx={{
                fontSize: { xs: "14px", md: "16px" },
                color: "#D9D8D8",
                ".MuiSelect-icon": {
                  color: "#F2F2F2",
                },
              }}
              IconComponent={ExpandMoreIcon}
            >
              <MenuItem value="Monthly">Monthly</MenuItem>
              <MenuItem value="Weekly">Weekly</MenuItem>
              <MenuItem value="Daily">Daily</MenuItem>
              <MenuItem value="Yearly">Yearly</MenuItem>
            </Select>
          </FormControl>
        </div>

        <LineChart
          colors={colorPalette}
          xAxis={[
            {
              scaleType: "point",
              data,
              tickInterval: (index, i) => isXsScreen 
                ? (i + 1) % 10 === 0 
                : isSmScreen 
                  ? (i + 1) % 7 === 0 
                  : (i + 1) % 5 === 0,
            },
          ]}
          series={[
            {
              id: "direct",
              label: "Direct",
              showMark: false,
              curve: "linear",
              stack: "total",
              area: true,
              stackOrder: "ascending",
              data: [
                300, 900, 500, 1200, 1500, 1800, 2400, 2100,
                2700, 3000, 1800, 3300, 3600, 3900, 4200, 4500,
                3900, 4800, 5100, 5400, 4500, 5700, 6000, 6300,
                6600, 6900, 7200, 7500, 7800, 8100,
              ],
              color: "#28ACFF",
            },
          ]}
          height={getChartHeight()}
          margin={getChartMargin()}
          grid={{ horizontal: true }}
          sx={{
            "& .MuiAreaElement-series-direct": {
              fill: "url('#direct')",
            },
          }}
          slotProps={{
            legend: {
              hidden: true,
            },
          }}
        >
          <AreaGradient
            color={theme.palette.primary.main}
            id="direct"
          />
        </LineChart>
      </CardContent>
    </Card>
  );
}