import * as React from "react";
import { useTheme } from "@mui/material/styles";
import {
	Card,
	CardContent,
	Typography,
	Box,
	Select,
	MenuItem,
	FormControl,
	SelectChangeEvent,
} from "@mui/material";
import { BarChart } from "@mui/x-charts/BarChart";
import { axisClasses } from "@mui/x-charts/ChartsAxis";
import ExpandMoreIcon from "@mui/icons-material/ExpandMore";
import useMediaQuery from "@mui/material/useMediaQuery";

// Sample Data
const data = [
	{ name: "Jan", v1: 40 },
	{ name: "Feb", v1: 50 },
	{ name: "Mar", v1: 80 },
	{ name: "Apr", v1: 20 },
	{ name: "May", v1: 60 },
	{ name: "Jun", v1: 30 },
];

export default function RoundedBarChart() {
	const theme = useTheme();
	const isXsScreen = useMediaQuery(theme.breakpoints.down("sm"));
	const isSmScreen = useMediaQuery(theme.breakpoints.between("sm", "md"));
	const [selectedOption, setSelectedOption] = React.useState("Monthly");

	const handleChange = (event: SelectChangeEvent<string>) => {
		setSelectedOption(event.target.value);
	};

	// Responsive chart settings
	const getChartSettings = () => {
		const baseSettings = {
     
			yAxis: [
				{
					label: isXsScreen ? "" : "Value",
					tickFormatter: (value: number) => `${value}`,
				},
			],
			xAxis: [
				{
					dataKey: "name",
					scaleType: "band" as const,
				},
			],
			sx: {
				[`.${axisClasses.left} .${axisClasses.label}`]: {
					transform: "translate(-10px, 0)",
				},
			},
		};

		// Screen-specific settings
		if (isXsScreen) {
			return {
				...baseSettings,
				width: 280,
				height: 220,
			};
		} else if (isSmScreen) {
			return {
				...baseSettings,
				width: 380,
				height: 260,
			};
		} else {
			return {
				...baseSettings,
				width: 500,
				height: 280,
			};
		}
	};

	const chartSetting = getChartSettings();

	return (
		<Card
			variant="outlined"
			sx={{
				width: "100%",
				height: "auto",
				minHeight: { xs: "360px", sm: "400px", md: "444px" },
				borderRadius: "16px",
				border: "none",
				"*:where([data-mui-color-scheme='dark']) &": {
					backgroundColor: "#202020",
				},
			}}
		>
			<CardContent
				sx={{
					padding: { xs: 2, md: 3 },
					"&:last-child": { paddingBottom: { xs: 2, md: 3 } },
				}}
			>
				<Box
					display="flex"
					alignItems="center"
					color="#F2F2F2"
					flexDirection={isXsScreen ? "column" : "row"}
					sx={{ mb: isXsScreen ? 2 : 0 }}
				>
					<Typography
						variant="h6"
						color="#F2F2F2"
						align={isXsScreen ? "center" : "left"}
						sx={{
							fontWeight: 500,
							fontSize: { xs: "16px", sm: "17px", md: "18px" },
							lineHeight: "24px",
							marginBottom: isXsScreen ? 2 : 0,
							width: isXsScreen ? "100%" : "auto",
						}}
					>
						Charge Stats
					</Typography>

					<FormControl
						sx={{
							mt: isXsScreen ? 0 : 2,
							ml: isXsScreen ? 0 : "auto",
							backgroundColor: "#202020",
							color: "#F2F2F2",
							width: { xs: "100%", sm: "140px", md: "149px" },
							height: { xs: "40px", md: "44px" },
							padding: { xs: "8px 12px", md: "12px 16px" },
							gap: "8px",
						}}
					>
						<Select
							value={selectedOption}
							onChange={handleChange}
							sx={{
								fontSize: { xs: "14px", md: "16px" },
								color: "#D9D8D8",
								".MuiSelect-icon": {
									color: "#F2F2F2",
								},
							}}
							IconComponent={ExpandMoreIcon}
						>
							<MenuItem value="Monthly">Monthly</MenuItem>
							<MenuItem value="Weekly">Weekly</MenuItem>
							<MenuItem value="Daily">Daily</MenuItem>
							<MenuItem value="Yearly">Yearly</MenuItem>
						</Select>
					</FormControl>
				</Box>

				<Box
					sx={{
						display: "flex",
						justifyContent: "center",
						alignItems: "center",
						width: "100%",
						mt: 2,
					}}
				>
					<BarChart
						borderRadius={0}
						dataset={data}
						series={[
							{
								dataKey: "v1",
								color: "#52ACDF",
							},
						]}
						layout="vertical"
						{...chartSetting}
					/>
				</Box>
			</CardContent>
		</Card>
	);
}
